==> 0.3.0.tar.gz: lib/src/ui/font_categories.dart <==
import 'package:flutter/material.dart';
import '../constants/constants.dart';

class FontCategories extends StatefulWidget {
  final ValueChanged<List<String>> onFontCategoriesUpdated;
  const FontCategories({Key? key, required this.onFontCategoriesUpdated})
      : super(key: key);

  @override
  _FontCategoriesState createState() => _FontCategoriesState();
}

class _FontCategoriesState extends State<FontCategories> {
  List<String> _selectedFontCategories = List.from(googleFontCategories);

  @override
  Widget build(BuildContext context) {
    return Wrap(
        children: googleFontCategories.map((fontCategory) {
      bool isSelectedCategory = _selectedFontCategories.contains(fontCategory);
      return SizedBox(
        height: 30.0,
        child: Padding(
          padding: const EdgeInsets.all(2.0),
          child: OutlinedButton(
            style: OutlinedButton.styleFrom(
                backgroundColor:
                    isSelectedCategory ? Theme.of(context).primaryColor : null,
                textStyle: TextStyle(
                  fontSize: 10.0,
                ),
                shape: StadiumBorder()),
            child: Text(fontCategory,
                style: TextStyle(
                  color: isSelectedCategory ? Colors.white : null,
                )),
            onPressed: () {
              _selectedFontCategories.contains(fontCategory)
                  ? _selectedFontCategories.remove(fontCategory)
                  : _selectedFontCategories.add(fontCategory);
              widget.onFontCategoriesUpdated(_selectedFontCategories);
            },
          ),
        ),
      );
    }).toList());
  }
}

==> 0.3.3.tar.gz: lib/src/ui/font_categories.dart <==
import 'package:flutter/material.dart';

import '../constants/constants.dart';

class FontCategories extends StatefulWidget {
  final ValueChanged<List<String>> onFontCategoriesUpdated;
  const FontCategories({Key? key, required this.onFontCategoriesUpdated})
      : super(key: key);

  @override
  _FontCategoriesState createState() => _FontCategoriesState();
}

class _FontCategoriesState extends State<FontCategories> {
  List<String> _selectedFontCategories = List.from(googleFontCategories);

  @override
  Widget build(BuildContext context) {
    return Wrap(
        children: googleFontCategories.map((fontCategory) {
      bool isSelectedCategory = _selectedFontCategories.contains(fontCategory);
      return SizedBox(
        height: 30.0,
        child: Padding(
          padding: const EdgeInsets.all(2.0),
          child: OutlinedButton(
            style: OutlinedButton.styleFrom(
                backgroundColor:
                    isSelectedCategory ? Theme.of(context).primaryColor : null,
                textStyle: TextStyle(
                  fontSize: 10.0,
                ),
                shape: StadiumBorder()),
            child: Text(fontCategory,
                style: TextStyle(
                  color: isSelectedCategory
                      ? Theme.of(context).colorScheme.onPrimary
                      : null,
                )),
            onPressed: () {
              _selectedFontCategories.contains(fontCategory)
                  ? _selectedFontCategories.remove(fontCategory)
                  : _selectedFontCategories.add(fontCategory);
              widget.onFontCategoriesUpdated(_selectedFontCategories);
            },
          ),
        ),
      );
    }).toList());
  }
}
